==> Mudlib-CD.00.28.tar.gz: lib/secure/armageddon.c <==
/*
   /secure/armageddon.c

   This object takes the mud down in a gracefull manner

   This is supposed to be inherited by the actual Armageddon object that
   handles transportation to shops etc.

*/
inherit "/std/creature";
#include <std.h>
#include <stdproperties.h>

#define TELLALL(x) "/cmd/wiz_cmd_normal"->tellall(x)

static	int	shutting;

create_creature()
{
    set_name("armageddon");
    set_short("small statuette");
    set_long("It is a small statuette of Armageddon!\n");
    set_living_name("armageddon");
    add_prop(LIVE_I_ALWAYSKNOWN, 1);
}

/*
 * Description:	This is called from master when the game should go down.
 */
static void slow_shut(string reason, int stime)
{
    set_this_player(this_object());
    TELLALL("Lo and behold! " + reason + " I am here!");
    TELLALL("Tell me if you want to be sent home.");
    this_object()->set_tell_active(1); /* We want all messages sen to us */

    this_object()->do_shut_down(({ this_player(), stime, reason }));
    shutting = 1;
}

/*
 * Tells Armageddon to shut down game
 * Returns 1 if shutdown initialized
 */
public int
shut_for_reason(string reason, int stime)
{
    /* There can be only one!
     */
    if (shutting)
	return 0;

    if (geteuid(previous_object()) != SECURITY->get_root_uid() &&
	previous_object() != this_object() &&
	previous_object() != find_object(WIZ_CMD_ARCH) &&
	previous_object() != find_object(WIZ_CMD_KEEPER))
	return 0;

    slow_shut(reason, stime);
    return 1;
}

void
do_shut_down(mixed info)
{
    int il;

    if (info[1])
    {
	if (intp(info[1]) && info[1] == 1)
	    TELLALL("I will shut the game down in 1 minute!");
	else
	    TELLALL("I will shut the game down in " + info[1] + " minutes!");
	call_out("do_shut_down", 60, ({ info[0], info[1] - 1, info[2] }));
	return;
    }

    TELLALL("I am shutting the game down now!");

    seteuid(SECURITY->get_root_uid());
    if (!SECURITY->master_shutdown("Armageddon: " + info[2]))
	write("Ooops, master do not allow us to shut down the game!\n");
}

void catch_tell(string str)
{
    string home;
    object old;

    if (this_player() == this_object())
	return;

    if (sizeof(explode(" " + str + " ", "home")) > 1)
    {
	home = this_player()->query_temp_start_location();
	if (!stringp(home))
	    home = this_player()->query_default_start_location();
	if (!stringp(home))
	    tell_object(this_player(),
		"Armageddon tells you: You have no home, sorry!\n");
	else
	{
	    old = environment(this_player());
	    tell_object(this_player(),
		"Armageddon tells you: I will try to send you home " +
		"to where you start!\n");
	    /* Third argument idicates group should not try to follow this
	     * player. */
	    this_player()->move_living("X", home, 1);
	    if (old == environment(this_player()))
		tell_object(this_player(),
		    "Armageddon tells you: My magic seems not to work " +
		    "too well at teleportation.\n");
	}
	    
    }
    else
	tell_object(this_player(),
	    "Armageddon tells you: Tell me 'home' and I will send you " +
	    "there.\n");
}

==> Mudlib-CD.00.30.tar.gz: lib/secure/armageddon.c <==
/*
   /secure/armageddon.c

   This object takes the mud down in a gracefull manner

   This is supposed to be inherited by the actual Armageddon object that
   handles transportation to shops etc.

*/
inherit "/std/creature";
#include <std.h>
#include <stdproperties.h>

#define TELLALL(x) "/cmd/wiz_cmd_normal"->tellall(x)

static	int	shutting;

create_creature()
{
    set_name("armageddon");
    set_short("small statuette");
    set_long("It is a small statuette of Armageddon!\n");
    set_living_name("armageddon");
    add_prop(LIVE_I_ALWAYSKNOWN, 1);
}

/*
 * Description:	This is called from master when the game should go down.
 */
static void slow_shut(string reason, int stime)
{
    set_this_player(this_object());
    TELLALL("Lo and behold! " + reason + " I am here!");
    TELLALL("Tell me (not commune) if you want to be sent home.");
    this_object()->set_tell_active(1); /* We want all messages sen to us */

    this_object()->do_shut_down(({ this_player(), stime, reason }));
    shutting = 1;
}

/*
 * Tells Armageddon to shut down game
 * Returns 1 if shutdown initialized
 */
public int
shut_for_reason(string reason, int stime)
{
    /* There can be only one!
     */
    if (shutting)
	return 0;

    if (geteuid(previous_object()) != SECURITY->get_root_uid() &&
	previous_object() != this_object() &&
	previous_object() != find_object(WIZ_CMD_ARCH) &&
	previous_object() != find_object(WIZ_CMD_KEEPER))
	return 0;

    slow_shut(reason, stime);
    return 1;
}

void
do_shut_down(mixed info)
{
    int il;

    if (info[1])
    {
	if (intp(info[1]) && info[1] == 1)
	    TELLALL("I will shut the game down in 1 minute!");
	else
	    TELLALL("I will shut the game down in " + info[1] + " minutes!");
	call_out("do_shut_down", 60, ({ info[0], info[1] - 1, info[2] }));
	return;
    }

    TELLALL("I am shutting the game down now!");

    seteuid(SECURITY->get_root_uid());
    if (!SECURITY->master_shutdown("Armageddon: " + info[2]))
	write("Ooops, master do not allow us to shut down the game!\n");
}

void catch_tell(string str)
{
    string home;
    object old;

    if (this_player() == this_object())
	return;

    if (sizeof(explode(" " + str + " ", "home")) > 1)
    {
	home = this_player()->query_temp_start_location();
	if (!stringp(home))
	    home = this_player()->query_default_start_location();
	if (!stringp(home))
	    tell_object(this_player(),
		"Armageddon tells you: You have no home, sorry!\n");
	else
	{
	    old = environment(this_player());
	    tell_object(this_player(),
		"Armageddon tells you: I will try to send you home " +
		"to where you start!\n");
	    /* Third argument idicates group should not try to follow this
	     * player. */
	    this_player()->move_living("X", home, 1);
	    if (old == environment(this_player()))
		tell_object(this_player(),
		    "Armageddon tells you: My magic seems not to work " +
		    "too well at teleportation.\n");
	}
	    
    }
    else
	tell_object(this_player(),
	    "Armageddon tells you: Tell me 'home' and I will send you " +
	    "there.\n");
}
